pub enum ValidationStatus {
Valid,
MaybeValid,
Invalid,
}Variants
Valid
All possible checks are done and passed.
MaybeValid
Some checks could not be performed for lack of information, all others passed. E.g. Signatures are valid, but no timestamps are present so they could have been created outside the time period in which the signer key was valid.
Invalid
Any step of validation failed.